%define module	django
%define tarname	Django

Summary:	A high-level Python Web framework
Name:		python-%{module}
Version:	1.8.11
Release:	%mkrel 1
Source0:	https://pypi.python.org/packages/source/D/%{tarname}/%{tarname}-%{version}.tar.gz
Patch0:		python-django-1.7-py3-admin-completion
License:	BSD
Group:		Development/Python
Url:		http://www.djangoproject.com
BuildArch:	noarch
BuildRequires:	python-setuptools
BuildRequires:	python-sphinx
BuildRequires:	python-devel
BuildRequires:	python3-devel
BuildRequires:	python3-setuptools
Requires:       %{name}-bash-completion = %{version}-%{release}

%description
Django is a high-level Python Web framework that encourages rapid development
and clean, pragmatic design.

Developed and used over the past two years by a fast-moving online-news
operation, Django was designed from scratch to handle two challenges: the
intensive deadlines of a newsroom and the stringent requirements of experienced
Web developers. It has convenient niceties for developing content-management
systems, but it's an excellent tool for building any Web site.

Django focuses on automating as much as possible and adhering to the
DRY principle.

%package bash-completion
Group:      Development/Python
Summary:    bash completion files for Django


%description bash-completion
This package contains the bash completion files form Django high-level
Python Web framework.

%package -n python3-%{module}
Summary:	A high-level Python Web framework
Group:		Development/Python
Requires:   %{name}-bash-completion = %{version}-%{release}

%description -n python3-%{module}

Django is a high-level Python Web framework that encourages rapid development
and clean, pragmatic design.

Developed and used over the past two years by a fast-moving online-news
operation, Django was designed from scratch to handle two challenges: the
intensive deadlines of a newsroom and the stringent requirements of experienced
Web developers. It has convenient niceties for developing content-management
systems, but it's an excellent tool for building any Web site.

Django focuses on automating as much as possible and adhering to the
DRY principle.

%package doc
Summary:	Documentation for django
Group:		Development/Python
Provides:	python3-%{module}-doc = %{version}-%{release}

%description doc
This package contains documentation for Django,
a high-level Python Web framework.

%prep
%setup -q -n %{tarname}-%{version}
%patch0

# empty files
for f in \
    django/contrib/staticfiles/models.py \
    django/contrib/webdesign/models.py \
    django/contrib/humanize/models.py \
; do
  echo "# just a comment" > $f
done
cp -a . %{py3dir}

%build
%{__python} setup.py build
pushd %{py3dir}
%{__python3} setup.py build
popd

%install
# must do install of python 3 subpackage first, so that we don't
# overwrite django-admin script with the python 3 version
pushd %{py3dir}
%{__python3} setup.py install --skip-build --root %{buildroot}
mv %{buildroot}%{_bindir}/django-admin.py %{buildroot}%{_bindir}/python3-django-admin
popd

%{__python} setup.py install --skip-build --root %{buildroot}

# build documentation
(cd docs && mkdir djangohtml && mkdir -p _build/{doctrees,html} && make html)


# install man pages
mkdir -p %{buildroot}%{_mandir}/man1/
cp -p docs/man/* %{buildroot}%{_mandir}/man1/
cp -a %{buildroot}%{_mandir}/man1/django-admin.1 %{buildroot}%{_mandir}/man1/python3-django-admin.1

# install bash completion script
mkdir -p %{buildroot}%{_sysconfdir}/bash_completion.d/
install -m 0644 -p extras/django_bash_completion \
   %{buildroot}%{_sysconfdir}/bash_completion.d/

# Fix items in %%{_bindir}
mv %{buildroot}%{_bindir}/django-admin.py %{buildroot}%{_bindir}/django-admin


%files
%doc AUTHORS LICENSE README.rst
%{_mandir}/man1/*
# except the python3 prefix
%exclude %{_mandir}/man1/python3-*
%{_bindir}/django-admin
%{python_sitelib}/%{module}
%{python_sitelib}/%{tarname}-*.egg-info

%files -n python3-%{module}
%doc AUTHORS LICENSE README.rst
%{_mandir}/man1/python3-*
%{_bindir}/python3-django-admin
%{python3_sitelib}/%{module}
%{python3_sitelib}/%{tarname}-*.egg-info

%files doc
%doc docs/_build/html

%files bash-completion
%dir %{_sysconfdir}/bash_completion.d/
%config(noreplace) %{_sysconfdir}/bash_completion.d/django_bash_completion



%changelog
* Tue Mar 08 2016 philippem <philippem> 1.8.11-1.mga5
+ Revision: 987568
- update to 1.8.11
- update to 1.8.10, fix CVE-2016-2512 and CVE-2016-2513 mga#17860
- update to 1.8.7, security fix for CVE-2015-8213 mga#17215
- security issues CVE-2015-5963 and CVE-2015-5964 mga#16607
- update to 1.8.3, fix mga#16334 CVE-2015-5143 CVE-2015-5144 CVE-2015-5145

* Fri May 22 2015 luigiwalser <luigiwalser> 1.8.2-1.mga5
+ Revision: 822596
- 1.8.2 (fixes CVE-2015-3982)

* Sat Apr 04 2015 philippem <philippem> 1.8-1.mga5
+ Revision: 819717
- update to 1.8 (LTS)

* Fri Mar 20 2015 luigiwalser <luigiwalser> 1.7.7-2.mga5
+ Revision: 819008
- rebuild for release

* Thu Mar 19 2015 philippem <philippem> 1.7.7-1.mga5
+ Revision: 818959
- update to 1.7.7, fix CVE-2015-2317 CVE-2015-2316 mga#15528

* Thu Jan 15 2015 philippem <philippem> 1.7.3-1.mga5
+ Revision: 810764
- Update to 1.7.3, security fix mga#15045

* Wed Oct 15 2014 umeabot <umeabot> 1.7-4.mga5
+ Revision: 746238
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.7-3.mga5
+ Revision: 727999
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.7-2.mga5
+ Revision: 687966
- Mageia 5 Mass Rebuild

* Wed Sep 03 2014 philippem <philippem> 1.7-1.mga5
+ Revision: 671692
- update to 1.7

* Thu Aug 21 2014 philippem <philippem> 1.6.6-1.mga5
+ Revision: 666261
- update to 1.6.6, security fix for CVE-2014-0481, CVE-2014-0482, CVE-2014-0483

* Sat May 31 2014 pterjan <pterjan> 1.6.5-2.mga5
+ Revision: 628550
- Rebuild for new Python

* Thu May 15 2014 oden <oden> 1.6.5-1.mga5
+ Revision: 622907
- 1.6.5 (fixes CVE-2014-1418, CVE-2014-3730)

* Thu Apr 24 2014 philippem <philippem> 1.6.3-2.mga5
+ Revision: 617661
- fix regression with upstream patch dj#22486

* Tue Apr 22 2014 philippem <philippem> 1.6.3-1.mga5
+ Revision: 617465
- 1.6.3 (fixes CVE-2014-0472, CVE-2014-0473, CVE-2014-0474)

* Mon Apr 07 2014 philippem <philippem> 1.6.2-1.mga5
+ Revision: 612783
- update to 1.6.2

* Tue Oct 22 2013 umeabot <umeabot> 1.5.4-3.mga4
+ Revision: 543295
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.5.4-2.mga4
+ Revision: 498360
- Rebuild to add different pythonegg provides for python 2 and 3

* Mon Sep 16 2013 oden <oden> 1.5.4-1.mga4
+ Revision: 480299
- 1.5.4 (fixes CVE-2013-1443)

* Wed Sep 11 2013 philippem <philippem> 1.5.3-1.mga4
+ Revision: 477685
- update to 1.5.3, security fix for CVE-2013-4315

* Wed Sep 04 2013 philippem <philippem> 1.5.2-1.mga4
+ Revision: 475168
- split doc in subpackage

  + marja <marja>
    - update to 1.5.2 and add python3
    - clean spec
    - removed PYTHONDONTWRITEBYTECODE= (mga#3348)

* Wed Aug 14 2013 oden <oden> 1.4.6-1.mga4
+ Revision: 466252
- 1.4.6 (security release)

* Tue Feb 26 2013 dmorgan <dmorgan> 1.4.5-1.mga3
+ Revision: 400426
- New version

* Sun Jan 13 2013 umeabot <umeabot> 1.4.3-2.mga3
+ Revision: 378662
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 13 2012 shlomif <shlomif> 1.4.3-1.mga3
+ Revision: 330338
- New version 1.4.3

* Thu Oct 18 2012 philippem <philippem> 1.4.2-1.mga3
+ Revision: 308004
- Fix security issues (https://www.djangoproject.com/weblog/2012/oct/17/security/)

* Sun Aug 12 2012 philippem <philippem> 1.4.1-1.mga3
+ Revision: 280862
- Fix #6986 several security issues.
- CVE-2012-3442: Cross-site scripting in authentication views
- CVE-2012-3443: Denial-of-service in image validation
- CVE-2012-3444: Denial-of-service via get_image_dimensions()

* Wed Jul 18 2012 obgr_seneca <obgr_seneca> 1.4-1.mga3
+ Revision: 272259
- new version 1.4

* Mon Sep 12 2011 misc <misc> 1.3.1-1.mga2
+ Revision: 142749
- upgrade to 1.3.1
- clean the specs file

* Mon Apr 18 2011 misc <misc> 1.3-1.mga1
+ Revision: 87658
- update to latest stable version of django

* Mon Feb 21 2011 ahmad <ahmad> 1.2.3-5.mga1
+ Revision: 55680
- resubmit, now that python-sphinx can be installed
- rebuild to make all pythonegg requires/provides lowercase

* Wed Feb 02 2011 dmorgan <dmorgan> 1.2.3-3.mga1
+ Revision: 46241
- imported package python-django

